==> reacl-c-0.11.9.jar: META-INF/leiningen/de.active-group/reacl-c/README.md <==
<img src="https://raw.githubusercontent.com/active-group/reacl-c/master/logo.png" width="180">

This is a web programming library for ClojureScript, founding
on Facebook's React. It's highly composable and embraces the functional
programming paradigm of Clojure.

[![Latest Version](https://img.shields.io/clojars/v/de.active-group/reacl-c.svg)](https://clojars.org/de.active-group/reacl-c)
[![Tests Status](https://github.com/active-group/reacl-c/workflows/Tests/badge.svg)](https://github.com/active-group/reacl-c/actions)

## Documentation

An introduction to the main concepts can be found [here](doc/intro.md).

The API documentation for the latest release is available [here](https://cljdoc.xyz/d/de.active-group/reacl-c/CURRENT).

For an example application take a look at the [Reacl-C TodoMVC](https://github.com/active-group/reacl-c-todomvc) implementation.

## Related libraries

For some auxiliary building blocks to build web applications, also
take a look at the accompanying library
[reacl-c-basics](https://github.com/active-group/reacl-c-basics).

For writing advanced tests of items and applications, see
[reacl-c-testing](https://github.com/active-group/reacl-c-testing).

And for migration from [Reacl](https://github.com/active-group/reacl)
or the general interop between Reacl-c and Reacl there is the
[reacl-c-reacl](https://github.com/active-group/reacl-c-reacl)
library.

## License

Copyright © 2020-2022 Active Group GmbH

Distributed under the Eclipse Public License either version 1.0 or (at
your option) any later version.

==> reacl-c-0.12.0.jar: META-INF/leiningen/de.active-group/reacl-c/README.md <==
<img src="https://raw.githubusercontent.com/active-group/reacl-c/master/logo.png" width="180">

This is a web programming library for ClojureScript, founding
on Facebook's React. It's highly composable and embraces the functional
programming paradigm of Clojure.

[![Latest Version](https://img.shields.io/clojars/v/de.active-group/reacl-c.svg)](https://clojars.org/de.active-group/reacl-c)
[![Tests Status](https://github.com/active-group/reacl-c/workflows/ci/badge.svg)](https://github.com/active-group/reacl-c/actions)

## Documentation

An introduction to the main concepts can be found [here](doc/intro.md).

The API documentation for the latest release is available [here](https://cljdoc.org/d/de.active-group/reacl-c/CURRENT).

For an example application take a look at the [Reacl-C TodoMVC](https://github.com/active-group/reacl-c-todomvc) implementation.

## Related libraries

For some auxiliary building blocks to build web applications, also
take a look at the accompanying library
[reacl-c-basics](https://github.com/active-group/reacl-c-basics).

For writing advanced tests of items and applications, see
[reacl-c-testing](https://github.com/active-group/reacl-c-testing).

And for migration from [Reacl](https://github.com/active-group/reacl)
or the general interop between Reacl-c and Reacl there is the
[reacl-c-reacl](https://github.com/active-group/reacl-c-reacl)
library.

## License

Copyright © 2020-2025 Active Group GmbH

Distributed under the Eclipse Public License either version 1.0 or (at
your option) any later version.
